#' @importFrom tibble tibble
#' @export
tibble::tibble
#' @importFrom dplyr mutate
#' @export
dplyr::mutate
#' @importFrom dplyr filter
#' @export
dplyr::filter
#' @importFrom dplyr group_by
#' @export
dplyr::group_by
#' @importFrom dplyr select
#' @export
dplyr::select
#' @importFrom dplyr desc
#' @export
dplyr::desc
#' @importFrom tidyr drop_na
#' @export
tidyr::drop_na
#' @importFrom tidyr gather
#' @export
tidyr::gather
#' @importFrom tidyr spread
#' @export
tidyr::spread
#' @importFrom generics tidy
#' @export
generics::tidy
#' @importFrom generics augment
#' @export
generics::augment
#' @importFrom car Anova
#' @export
car::Anova
