% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-manova.R
\name{Manova}
\alias{Manova}
\title{Manova exported from car package}
\description{
See \code{car::\link[car:Anova]{Manova}} for details.
}
\keyword{internal}
