% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fligner_test.R
\name{fligner_test}
\alias{fligner_test}
\title{Fligner-Killeen Test}
\usage{
fligner_test(data, formula, ...)
}
\arguments{
\item{data}{a data.frame containing the variables in the formula.}

\item{formula}{a formula of the form \code{x ~ group} where \code{x} is a
numeric variable giving the data values and \code{group} is a factor with
one or multiple levels giving the corresponding groups. For example,
\code{formula = TP53 ~ cancer_group}.}

\item{...}{other arguments to be passed to the function
\code{\link[stats]{fligner.test}}.}
}
\value{
return a data frame with the following columns: \itemize{ \item
 \code{.y.}: the y variable used in the test. \item \code{n}: sample count.
 \item \code{statistic}: the Fligner-Killeen test statistic (a chi-squared
 statistic) used to compute the p-value. \item \code{df}: the degrees of
 freedom. \item \code{p}: p-value. \item \code{method}: the statistical test
 used to compare groups.}
}
\description{
Provides a pipe-friendly framework to perform the Fligner-Killeen
 test, a non-parametric (rank-based) test of the homogeneity of group
 variances. It is robust against departures from normality and is a useful
 alternative to \code{\link{levene_test}()}. Wrapper around the function
 \code{\link[stats]{fligner.test}()}.
}
\examples{
# Load data
#:::::::::::::::::::::::::::::::::::::::
data("ToothGrowth")
df <- ToothGrowth

# Fligner-Killeen test
#:::::::::::::::::::::::::::::::::::::::::
df \%>\% fligner_test(len ~ dose)

# Grouped data
df \%>\%
  group_by(supp) \%>\%
  fligner_test(len ~ dose)
}
\seealso{
\code{\link{levene_test}}
}
