% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_clean_names.R
\name{make_clean_names}
\alias{make_clean_names}
\title{Make Clean Names}
\usage{
make_clean_names(data)
}
\arguments{
\item{data}{a data frame or vector}
}
\value{
a data frame or a vector depending on the input data
}
\description{
Pipe-friendly function to make syntactically valid names out of
 character vectors.
}
\examples{

# Vector
make_clean_names(c("a and b", "a-and-b"))
make_clean_names(1:10)

# data frame
df <- data.frame(
`a and b` = 1:4,
`c and d` = 5:8,
 check.names = FALSE
)
df
make_clean_names(df)

}
