% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reexports.R
\docType{import}
\name{reexports}
\alias{reexports}
\alias{tibble}
\alias{mutate}
\alias{filter}
\alias{group_by}
\alias{select}
\alias{desc}
\alias{drop_na}
\alias{gather}
\alias{spread}
\alias{tidy}
\alias{augment}
\alias{Anova}
\title{Objects exported from other packages}
\keyword{internal}
\description{
These objects are imported from other packages. Follow the links
below to see their documentation.

\describe{
  \item{car}{\code{\link[car]{Anova}}}

  \item{dplyr}{\code{\link[dplyr]{desc}}, \code{\link[dplyr]{filter}}, \code{\link[dplyr]{group_by}}, \code{\link[dplyr]{mutate}}, \code{\link[dplyr]{select}}}

  \item{generics}{\code{\link[generics]{augment}}, \code{\link[generics]{tidy}}}

  \item{tibble}{\code{\link[tibble]{tibble}}}

  \item{tidyr}{\code{\link[tidyr]{drop_na}}, \code{\link[tidyr]{gather}}, \code{\link[tidyr]{spread}}}
}}

